@@ -8,6 +8,6 @@ def resource_group(stem, props, provider=None, parent_res=None, depends_on=None)
         resource_group_name=f'rg-{stem}',
         tags=props.tags,
         location=props.location,
-        opts=ResourceOptions(provider=provider, parent=parent_res,depends_on=depends_on)
+        opts=ResourceOptions(parent=parent_res,depends_on=depends_on)
     )
     return rg
\ No newline at end of file
